A sample flight query object created with `fa_define_query()`. Useful for testing and documentation examples without making API calls.
A sample flight query object created with `fa_define_query()`. Useful for testing and documentation examples without making API calls.